@@ -122,37 +122,56 @@ func fieldsN(s string, n int) []string {
 }
 
 func init() {
-	StringType.Dict["split"] = MustNewMethod("split", func(self Object, args Tuple) (Object, error) {
-		selfStr := self.(String)
-		var value Object = None
-		zeroRemove := true
+	StringType.Dict["endswith"] = MustNewMethod("endswith", func(self Object, args Tuple) (Object, error) {
+		selfStr := string(self.(String))
+		suffix := []string{}
 		if len(args) > 0 {
-			if _, ok := args[0].(NoneType); !ok {
-				value = args[0]
-				zeroRemove = false
+			if s, ok := args[0].(String); ok {
+				suffix = append(suffix, string(s))
+			} else if s, ok := args[0].(Tuple); ok {
+				for _, t := range s {
+					if v, ok := t.(String); ok {
+						suffix = append(suffix, string(v))
+					}
+				}
+			} else {
+				return nil, ExceptionNewf(TypeError, "endswith first arg must be str, unicode, or tuple, not %s", args[0].Type())
 			}
-		}
-		var maxSplit int = -2
-		if len(args) > 1 {
-			if m, ok := args[1].(Int); ok {
-				maxSplit = int(m)
-			}
-		}
-		var valArray []string
-		if valStr, ok := value.(String); ok {
-			valArray = strings.SplitN(string(selfStr), string(valStr), maxSplit+1)
-		} else if _, ok := value.(NoneType); ok {
-			valArray = fieldsN(string(selfStr), maxSplit)
 		} else {
-			return nil, ExceptionNewf(TypeError, "Can't convert '%s' object to str implicitly", value.Type())
+			return nil, ExceptionNewf(TypeError, "endswith() takes at least 1 argument (0 given)")
 		}
-		o := List{}
-		for _, j := range valArray {
-			if len(j) > 0 || !zeroRemove {
-				o.Items = append(o.Items, String(j))
+		for _, s := range suffix {
+			if strings.HasSuffix(selfStr, s) {
+				return Bool(true), nil
 			}
 		}
-		return &o, nil
+		return Bool(false), nil
+	}, 0, "endswith(suffix[, start[, end]]) -> bool")
+
+	StringType.Dict["find"] = MustNewMethod("find", func(self Object, args Tuple) (Object, error) {
+		return self.(String).find(args)
+	}, 0, `find(...)
+S.find(sub[, start[, end]]) -> int
+
+Return the lowest index in S where substring sub is found,
+such that sub is contained within S[start:end].  Optional
+arguments start and end are interpreted as in slice notation.
+
+Return -1 on failure.`)
+
+	StringType.Dict["replace"] = MustNewMethod("replace", func(self Object, args Tuple) (Object, error) {
+		return self.(String).Replace(args)
+	}, 0, `replace(self, old, new, count=-1) -> return a copy with all occurrences of substring old replaced by new.
+
+  count
+    Maximum number of occurrences to replace.
+    -1 (the default value) means replace all occurrences.
+
+If the optional argument count is given, only the first count occurrences are
+replaced.`)
+
+	StringType.Dict["split"] = MustNewMethod("split", func(self Object, args Tuple, kwargs StringDict) (Object, error) {
+		return self.(String).Split(args, kwargs)
 	}, 0, "split(sub) -> split string with sub.")
 
 	StringType.Dict["startswith"] = MustNewMethod("startswith", func(self Object, args Tuple) (Object, error) {
@@ -187,31 +206,17 @@ func init() {
 		return Bool(false), nil
 	}, 0, "startswith(prefix[, start[, end]]) -> bool")
 
-	StringType.Dict["endswith"] = MustNewMethod("endswith", func(self Object, args Tuple) (Object, error) {
-		selfStr := string(self.(String))
-		suffix := []string{}
-		if len(args) > 0 {
-			if s, ok := args[0].(String); ok {
-				suffix = append(suffix, string(s))
-			} else if s, ok := args[0].(Tuple); ok {
-				for _, t := range s {
-					if v, ok := t.(String); ok {
-						suffix = append(suffix, string(v))
-					}
-				}
-			} else {
-				return nil, ExceptionNewf(TypeError, "endswith first arg must be str, unicode, or tuple, not %s", args[0].Type())
-			}
-		} else {
-			return nil, ExceptionNewf(TypeError, "endswith() takes at least 1 argument (0 given)")
-		}
-		for _, s := range suffix {
-			if strings.HasSuffix(selfStr, s) {
-				return Bool(true), nil
-			}
-		}
-		return Bool(false), nil
-	}, 0, "endswith(suffix[, start[, end]]) -> bool")
+	StringType.Dict["strip"] = MustNewMethod("strip", func(self Object, args Tuple, kwargs StringDict) (Object, error) {
+		return self.(String).Strip(args)
+	}, 0, "strip(chars) -> replace chars from begining and end of string")
+
+	StringType.Dict["rstrip"] = MustNewMethod("rstrip", func(self Object, args Tuple, kwargs StringDict) (Object, error) {
+		return self.(String).RStrip(args)
+	}, 0, "rstrip(chars) -> replace chars from end of string")
+
+	StringType.Dict["lstrip"] = MustNewMethod("lstrip", func(self Object, args Tuple, kwargs StringDict) (Object, error) {
+		return self.(String).LStrip(args)
+	}, 0, "lstrip(chars) -> replace chars from begining of string")
 
 }
 
@@ -307,7 +312,7 @@ func (a String) M__imul__(other Object) (Object, error) {
 
 // Convert an Object to an String
 //
-// Retrurns ok as to whether the conversion worked or not
+// Returns ok as to whether the conversion worked or not
 func convertToString(other Object) (String, bool) {
 	switch b := other.(type) {
 	case String:
@@ -363,7 +368,6 @@ func (a String) M__ge__(other Object) (Object, error) {
 // % operator
 
 /*
-
 4.7.2. printf-style String Formatting
 
 Note The formatting operations described here exhibit a variety of
@@ -597,13 +601,153 @@ func (s String) M__contains__(item Object) (Object, error) {
 	return NewBool(strings.Contains(string(s), string(needle))), nil
 }
 
+func (s String) find(args Tuple) (Object, error) {
+	var (
+		pysub Object
+		pybeg Object = Int(0)
+		pyend Object = Int(s.len())
+		pyfmt        = "s|ii:find"
+	)
+	err := ParseTuple(args, pyfmt, &pysub, &pybeg, &pyend)
+	if err != nil {
+		return nil, err
+	}
+
+	var (
+		beg  = int(pybeg.(Int))
+		end  = int(pyend.(Int))
+		size = s.len()
+	)
+	if beg > size {
+		beg = size
+	}
+	if end < 0 {
+		end = size
+	}
+	if end > size {
+		end = size
+	}
+
+	var (
+		off = s.slice(0, beg, s.len()).len()
+		str = string(s.slice(beg, end, s.len()))
+		sub = string(pysub.(String))
+		idx = strings.Index(str, sub)
+	)
+	if idx < 0 {
+		return Int(idx), nil
+	}
+	return Int(off + String(str[:idx]).len()), nil
+}
+
+func (s String) Split(args Tuple, kwargs StringDict) (Object, error) {
+	var (
+		pyval Object = None
+		pymax Object = Int(-2)
+		pyfmt        = "|Oi:split"
+		kwlst        = []string{"sep", "maxsplit"}
+	)
+	err := ParseTupleAndKeywords(args, kwargs, pyfmt, kwlst, &pyval, &pymax)
+	if err != nil {
+		return nil, err
+	}
+
+	var (
+		max = pymax.(Int)
+		vs  []string
+	)
+	switch v := pyval.(type) {
+	case String:
+		vs = strings.SplitN(string(s), string(v), int(max)+1)
+	case NoneType:
+		vs = fieldsN(string(s), int(max))
+	default:
+		return nil, ExceptionNewf(TypeError, "Can't convert '%s' object to str implicitly", pyval.Type())
+	}
+	o := List{}
+	for _, j := range vs {
+		o.Items = append(o.Items, String(j))
+	}
+	return &o, nil
+}
+
+func (s String) Replace(args Tuple) (Object, error) {
+	var (
+		pyold Object = None
+		pynew Object = None
+		pycnt Object = Int(-1)
+	)
+	err := ParseTuple(args, "ss|i:replace", &pyold, &pynew, &pycnt)
+	if err != nil {
+		return nil, err
+	}
+
+	var (
+		old = string(pyold.(String))
+		new = string(pynew.(String))
+		cnt = int(pycnt.(Int))
+	)
+
+	return String(strings.Replace(string(s), old, new, cnt)), nil
+}
+
+func stripFunc(args Tuple) (func(rune) bool, error) {
+	var (
+		pyval Object = None
+	)
+	err := ParseTuple(args, "|s", &pyval)
+	if err != nil {
+		return nil, err
+	}
+	f := unicode.IsSpace
+	switch v := pyval.(type) {
+	case String:
+		chars := []rune(string(v))
+		f = func(s rune) bool {
+			for _, i := range chars {
+				if s == i {
+					return true
+				}
+			}
+			return false
+		}
+	}
+	return f, nil
+}
+
+func (s String) Strip(args Tuple) (Object, error) {
+	f, err := stripFunc(args)
+	if err != nil {
+		return nil, err
+	}
+	return String(strings.TrimFunc(string(s), f)), nil
+}
+
+func (s String) LStrip(args Tuple) (Object, error) {
+	f, err := stripFunc(args)
+	if err != nil {
+		return nil, err
+	}
+	return String(strings.TrimLeftFunc(string(s), f)), nil
+}
+
+func (s String) RStrip(args Tuple) (Object, error) {
+	f, err := stripFunc(args)
+	if err != nil {
+		return nil, err
+	}
+	return String(strings.TrimRightFunc(string(s), f)), nil
+}
+
 // Check stringerface is satisfied
-var _ richComparison = String("")
-var _ sequenceArithmetic = String("")
-var _ I__mod__ = String("")
-var _ I__rmod__ = String("")
-var _ I__imod__ = String("")
-var _ I__len__ = String("")
-var _ I__bool__ = String("")
-var _ I__getitem__ = String("")
-var _ I__contains__ = String("")
+var (
+	_ richComparison     = String("")
+	_ sequenceArithmetic = String("")
+	_ I__mod__           = String("")
+	_ I__rmod__          = String("")
+	_ I__imod__          = String("")
+	_ I__len__           = String("")
+	_ I__bool__          = String("")
+	_ I__getitem__       = String("")
+	_ I__contains__      = String("")
+)
